﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Xml.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.ComponentModel;
using Infragistics.Windows.DockManager;
using BarclaysCapital.CR.PDC.Controls;

namespace BarclaysCapital.CR.PDC.Margin
{
    /// <summary>
    /// Interaction logic for CallAndAlertManager.xaml
    /// </summary>
    public partial class CallAndAlertManager : BackgroundWorkerControl
    {
        public CallAndAlertManager()
        {
            InitializeComponent();
        }

        public static string Header
        {
            get
            {
                return "Call & Alert Manager";
            }
        }

        public void SetData()
        {
            UpdateScreenBusyAnimation(true, dockManager, processingControl);
            TryRunWorkerAsync(null);
        }

        protected internal override void bwQuery_DoWork(object sender, DoWorkEventArgs e)
        {
            System.Threading.Thread.Sleep(3000);
        }

        protected internal override void bwQuery_RunWorkerCompleted(object sender, RunWorkerCompletedEventArgs e)
        {
            UpdateScreenBusyAnimation(false, dockManager, processingControl);
        }

        public void UpdateScreenBusyAnimation(bool showBusy, XamDockManager dockManager, ProcessingContentControl processingControl)
        {
            Visibility visibility = showBusy ? Visibility.Hidden : Visibility.Visible;

            // Hide any visible floating panes for the duration of the busy operation as the ProcessingContentControl doesn't cover floating panes
            foreach (ContentPane cpPane in dockManager.GetPanes(PaneNavigationOrder.ActivationOrder))
            {
                if (cpPane.PaneLocation == PaneLocation.Floating)
                {
                    PaneToolWindow toolWindow = cpPane.TryFindParent<PaneToolWindow>();

                    // For showing the screen as busy, only hide panes that are currently visible
                    if (visibility == Visibility.Hidden && toolWindow.Visibility == Visibility.Visible)
                    {
                        // Tag the pane to indicate its visibility must be restored at the end of the busy operation
                        toolWindow.Tag = toolWindow.Visibility;
                        toolWindow.Visibility = visibility;
                    }
                    // At the end of the busy operation, check the pane has been tagged to indicate to restore its visibility
                    else if (visibility == Visibility.Visible && toolWindow.Tag is Visibility && (Visibility)toolWindow.Tag == Visibility.Visible)
                    {
                        toolWindow.Tag = null;
                        toolWindow.Visibility = Visibility.Visible;
                    }
                }
            }

            processingControl.IsContentProcessing = showBusy;
        }
    }
}
